# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CalendarApi",
    "CandlesApi",
    "GeneralApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CalendarEvent",
    "Candle",
    "Info",
    "Metadata",
    "SearchResult",
]

# import apis into sdk package
from openapi_client.api.calendar_api import CalendarApi as CalendarApi
from openapi_client.api.candles_api import CandlesApi as CandlesApi
from openapi_client.api.general_api import GeneralApi as GeneralApi

# import ApiClient
from openapi_client.api_response import ApiResponse as ApiResponse
from openapi_client.api_client import ApiClient as ApiClient
from openapi_client.configuration import Configuration as Configuration
from openapi_client.exceptions import OpenApiException as OpenApiException
from openapi_client.exceptions import ApiTypeError as ApiTypeError
from openapi_client.exceptions import ApiValueError as ApiValueError
from openapi_client.exceptions import ApiKeyError as ApiKeyError
from openapi_client.exceptions import ApiAttributeError as ApiAttributeError
from openapi_client.exceptions import ApiException as ApiException

# import models into sdk package
from openapi_client.models.calendar_event import CalendarEvent as CalendarEvent
from openapi_client.models.candle import Candle as Candle
from openapi_client.models.info import Info as Info
from openapi_client.models.metadata import Metadata as Metadata
from openapi_client.models.search_result import SearchResult as SearchResult

