# coding: utf-8

# flake8: noqa
"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from tickcatcher.models.calendar_event import CalendarEvent
from tickcatcher.models.candle import Candle
from tickcatcher.models.info import Info
from tickcatcher.models.metadata import Metadata
from tickcatcher.models.search_result import SearchResult

