# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class Info(BaseModel):
    """
    Info
    """ # noqa: E501
    package_name: StrictStr = Field(description="The package that you are using.", alias="packageName")
    usable_coins: List[StrictStr] = Field(description="The usable coins list for your package.", alias="usableCoins")
    max_candles_on_request: StrictInt = Field(description="Maximum allowed candles for your package to fetch at one query.", alias="maxCandlesOnRequest")
    usable_timeframes: List[StrictStr] = Field(description="The timeframes that you can select on your queries.", alias="usableTimeframes")
    custom_date_selection: StrictBool = Field(description="Whether you can select start and end dates during queries.", alias="customDateSelection")
    __properties: ClassVar[List[str]] = ["packageName", "usableCoins", "maxCandlesOnRequest", "usableTimeframes", "customDateSelection"]

    @field_validator('package_name')
    def package_name_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['Basic', 'Pro', 'Ultra', 'Mega', 'Enterprise']):
            raise ValueError("must be one of enum values ('Basic', 'Pro', 'Ultra', 'Mega', 'Enterprise')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Info from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Info from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "packageName": obj.get("packageName"),
            "usableCoins": obj.get("usableCoins"),
            "maxCandlesOnRequest": obj.get("maxCandlesOnRequest"),
            "usableTimeframes": obj.get("usableTimeframes"),
            "customDateSelection": obj.get("customDateSelection")
        })
        return _obj


