# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CalendarApi",
    "CandlesApi",
    "GeneralApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CalendarEvent",
    "Candle",
    "Info",
    "Metadata",
    "SearchResult",
]

# import apis into sdk package
from tickcatcher.api.calendar_api import CalendarApi as CalendarApi
from tickcatcher.api.candles_api import CandlesApi as CandlesApi
from tickcatcher.api.general_api import GeneralApi as GeneralApi

# import ApiClient
from tickcatcher.api_response import ApiResponse as ApiResponse
from tickcatcher.api_client import ApiClient as ApiClient
from tickcatcher.configuration import Configuration as Configuration
from tickcatcher.exceptions import OpenApiException as OpenApiException
from tickcatcher.exceptions import ApiTypeError as ApiTypeError
from tickcatcher.exceptions import ApiValueError as ApiValueError
from tickcatcher.exceptions import ApiKeyError as ApiKeyError
from tickcatcher.exceptions import ApiAttributeError as ApiAttributeError
from tickcatcher.exceptions import ApiException as ApiException

# import models into sdk package
from tickcatcher.models.calendar_event import CalendarEvent as CalendarEvent
from tickcatcher.models.candle import Candle as Candle
from tickcatcher.models.info import Info as Info
from tickcatcher.models.metadata import Metadata as Metadata
from tickcatcher.models.search_result import SearchResult as SearchResult

