# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.calendar_event import CalendarEvent

class TestCalendarEvent(unittest.TestCase):
    """CalendarEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CalendarEvent:
        """Test CalendarEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CalendarEvent`
        """
        model = CalendarEvent()
        if include_optional:
            return CalendarEvent(
                title = '',
                country = '',
                indicator = '',
                ticker = '',
                comment = '',
                category = '',
                period = '',
                reference_date = '',
                source = '',
                source_url = '',
                actual = 1.337,
                previous = 1.337,
                forecast = 1.337,
                actual_raw = 1.337,
                previous_raw = 1.337,
                forecast_raw = 1.337,
                currency = '',
                unit = '',
                importance = 1.337,
                ts = 1.337,
                scale = ''
            )
        else:
            return CalendarEvent(
                title = '',
                country = '',
                importance = 1.337,
                ts = 1.337,
        )
        """

    def testCalendarEvent(self):
        """Test CalendarEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
