# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.metadata import Metadata

class TestMetadata(unittest.TestCase):
    """Metadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Metadata:
        """Test Metadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Metadata`
        """
        model = Metadata()
        if include_optional:
            return Metadata(
                symbol = 'BTCUSDT',
                timeframe = '1h',
                first_candle = '2025-10-01T00:00:00.000Z',
                last_candle = '2025-10-15T00:00:00.000Z',
                total_candles = 816,
                completion_percent = '99.52',
                estimated_completion_date = '2025-10-20T00:00:00.000Z'
            )
        else:
            return Metadata(
                symbol = 'BTCUSDT',
                timeframe = '1h',
                first_candle = '2025-10-01T00:00:00.000Z',
                last_candle = '2025-10-15T00:00:00.000Z',
                total_candles = 816,
                completion_percent = '99.52',
                estimated_completion_date = '2025-10-20T00:00:00.000Z',
        )
        """

    def testMetadata(self):
        """Test Metadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
